==> portmanager-0.2.9.tar.gz: portmanager-0.2.9/libMG/src/MGdbDelete.c <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

classDb*	MGdbDelete(classDb* db, int recordIdx )
{
	FILE*		dbFileStream;
	char		id[]		= "MGdbDelete";
	char*		newPath		= NULL;
	int		stringSize	= 0;
	static classDb*	newDb;
	
	/* check if we have a valid object */
	if(db == NULL || db->parent.type != CLASS_TYPE_DB)
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		assert(0);
	}

	db->parent.recordIdx	= 0;
	db->fieldIdx		= 0;

	/*zzzzzzzzzzzzzz*/
	db->parent.fopenIdx++;
	dbFileStream		= fopen( db->parent.path, "w" );	/* truncate original db file */
	/*zzzzzzzzzzzzzz*/

	/* write records before deleted record to disk */
	while( db->parent.recordIdx < recordIdx )
	{
		while( db->fieldIdx < db->fieldQty )
		{
			fprintf( dbFileStream, "%s%c", db->record[db->parent.recordIdx][db->fieldIdx], 0 );
			db->fieldIdx++;
		}
		fprintf( dbFileStream, "%c", LINEFEED );
		db->fieldIdx = 0;
		db->parent.recordIdx++;
	}

	/* write records after deleted record to disk */
	db->parent.recordIdx++;
	while( db->parent.recordIdx < db->parent.recordQty )
	{
		while( db->fieldIdx < db->fieldQty )
		{
			fprintf( dbFileStream, "%s%c", db->record[db->parent.recordIdx][db->fieldIdx], 0 );
			db->fieldIdx++;
		}
		fprintf( dbFileStream, "%c", LINEFEED );
		db->fieldIdx = 0;
		db->parent.recordIdx++;
	}

	db->parent.fopenIdx--;
	fclose( dbFileStream );

	stringSize		= strlen(db->parent.path) + 1;
	newPath			= (char*)malloc(stringSize);
	newPath[0]		= 0;
	strcpy(newPath, db->parent.path);
	newDb	= MGdbOpen( newPath );	
	MGdbDestroy( db );
	free( newPath );
	return(newDb);
}

==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMG/src/MGdbDelete.c <==
/************************************************************************/
/*	Copyright (C) 2004  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

classDb*	MGdbDelete( classDb* db, int recordIdx )
{
	FILE*		dbFileStream;
	char		id[]		= "MGdbDelete";
	static	char*	newPath		= NULL;
	int		stringSize	= 0;
	static	classDb*	newDb;
	
	/* check if we have a valid object */
	if(db == NULL || db->parent.type != CLASS_TYPE_DB)
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		return( NULL );
	}

	db->parent.recordIdx	= 0;
	db->fieldIdx		= 0;

	/*zzzzzzzzzzzzzz*/
	db->parent.fopenIdx++;

	/*
	 * truncate original db file
	 */
	if( ( dbFileStream = fopen( db->parent.path, "w" ) ) == NULL )
	{
		fprintf( stderr, "%s error: unable to open %s mode \"w\"\n", id, db->parent.path );
		perror( "system message" );
		return( NULL );
	}
	/*zzzzzzzzzzzzzz*/

	/* write records before deleted record to disk */
	while( db->parent.recordIdx < recordIdx )
	{
		while( db->fieldIdx < db->fieldQty )
		{
			fprintf( dbFileStream, "%s%c", db->record[db->parent.recordIdx][db->fieldIdx], 0 );
			db->fieldIdx++;
		}
		fprintf( dbFileStream, "%c", LINEFEED );
		db->fieldIdx = 0;
		db->parent.recordIdx++;
	}

	/* write records after deleted record to disk */
	db->parent.recordIdx++;
	while( db->parent.recordIdx < db->parent.recordQty )
	{
		while( db->fieldIdx < db->fieldQty )
		{
/*
fprintf( stdout, "%s DEBUG 1: db->record[%d][%d]  db->parent.recordQty-=>%d db->fieldQty-=>%d db->record[db->parent.recordIdx][db->fieldIdx][0]-=>%d\n",
	id, db->parent.recordIdx, db->fieldIdx, db->parent.recordQty, db->fieldQty, db->record[db->parent.recordIdx][db->fieldIdx][0] );
*/
			fprintf( dbFileStream, "%s%c", db->record[db->parent.recordIdx][db->fieldIdx], 0 );
			db->fieldIdx++;
		}
		fprintf( dbFileStream, "%c", LINEFEED );
		db->fieldIdx = 0;
		db->parent.recordIdx++;
	}

	db->parent.fopenIdx--;
	fclose( dbFileStream );
	stringSize		= strlen( db->parent.path ) + 1;
	newPath			= (char*)calloc( stringSize, 1 );
	strcpy( newPath, db->parent.path );
	MGdbDestroy( db );
	if( ( newDb = MGdbOpen( newPath ) ) == NULL )
	{
		fprintf( stderr, "%s error: unable to MGdbOpen %s\n", id, newPath );
		perror( "system message" );
		return( NULL );
	}
	db	= newDb;
	free( newPath );
	return( newDb );
}
